Intercalate list values into a vector
Value
vector of values derived from each input list ..., with
one element per list in order. In the event any list is shorter than
the others, its values are recycled so each list is equal length.
Details
This function takes a list of vectors, and intercalates them by inserting alternating values from each vector to make one combined vector. It is analogous to shuffling a deck of cards, except that there could be more than two stacks of cards shuffled together.
See also
Other Internal utility functions:
combineGRcoverage(),
compressPolygonM(),
df2colorSub(),
dfWide2segments(),
escapeWhitespaceRegexp(),
factor2label(),
geomean(),
internal_junc_score(),
jamGeomean(),
list2im(),
shrinkMatrix(),
simplifyXY(),
stackJunctions(),
strsplitOrdered()