Calculate a spline curve fit in 3-D
Arguments
- x
numeric vector or numeric
matrixordata.framewithcolnames(x)containingc("x","y","z").- y, z
optional numeric vectors, used only when x is also a numeric vector.
- lengthFactor
numeric multiplier used to control the number of intermediate points during smoothing between each provided point.
- verbose
logical indicating whether to print verbose output.
Details
This function takes 3-dimensional points as input, and fits
a 3-D spline curve to connect the points. It essentially calls
stats::spline() on one dimension at a time, relative to the
row rank.
See also
Other Plot utility functions:
bgaPlotly3d(),
jitter_norm()