Convert DNA to 3-base codons
Value
character vector where each element contains three characters,
e.g. all(nchar(dna2codon(x)) == 3).
Details
This function takes character string input, either as one large string or vector of strings such as those read from a FASTA file, and returns a vector of 3-base codons. The final codon must contain all three character values otherwise it is removed.
See also
Other ALE and codon functions:
ale2violin(),
codonUsage2df(),
getFirstStrandedFromGRL(),
jamCai(),
tx2ale()