read gtf/gff3 file
Arguments
- GTF
characterfile name sent todata.table::fread(). When the file ends with ".gz", theR.utilspackage is recommended, otherwise the fallback option is to make a system call togzcatto gunzip the file during the import step. Note this process fails whengzcatis not available in the path of the user environment. In general, theR.utilspackage is the best solution.- nrows
integernumber of rows to read from the GTF file, by default -1 means all rows are imported. This parameter is useful to check the results of a large GTF file using only a subset portion of the file.- zcat_command
charactername or path to zcat or gzcat executable, only used when inputGTFis a file with".gz"extension, and when R packageR.utilsis not available.- verbose
logicalwhether to print verbose output during processing.- ...
additional arguments are ignored.
See also
Other GTF functions:
describeGtfAttrNames(),
getGtfAttrs(),
makeTx2geneFromGtf(),
makeTx2geneFromTxdb()